@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10196 2017-08-19 15:11:43Z David $
+# $Id: StatisticsHandler.py 10214 2017-08-25 16:28:03Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-08-19 23:11:43 +0800 (Sat, 19 Aug 2017) $
-# $Revision: 10196 $
+# $Date: 2017-08-26 00:28:03 +0800 (Sat, 26 Aug 2017) $
+# $Revision: 10214 $
 
 from datetime import timedelta, datetime
 
@@ -595,11 +595,8 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                 #     totalValue = subscriberCount
                 #     totalValue = info['deliverie']        
                 
-                if i == 'open':            
-                    value = percentage(info['open'] + info['openOnSite'], 
-                                       totalValue, showPercent=False)
-                else:
-                    value = percentage(info[i], totalValue, showPercent=False)
+
+                value = percentage(info[i], totalValue, showPercent=False)
                 
                 rates.append((i, value))
             return rates
